[telepathy-gabble/master] export emit_presence_update

Dafydd Harries dafydd.harries at collabora.co.uk
Thu Sep 17 12:24:46 PDT 2009


---
 src/conn-presence.c |   16 +++++++++-------
 src/conn-presence.h |    2 ++
 2 files changed, 11 insertions(+), 7 deletions(-)

diff --git a/src/conn-presence.h b/src/conn-presence.h
index ba5f9df..0f25f7e 100644
--- a/src/conn-presence.h
+++ b/src/conn-presence.h
@@ -31,6 +31,8 @@ void conn_presence_class_init (GabbleConnectionClass *klass);
 void conn_presence_init (GabbleConnection *conn);
 void conn_presence_finalize (GabbleConnection *conn);
 void conn_presence_iface_init (gpointer g_iface, gpointer iface_data);
+void conn_presence_emit_presence_update (
+    GabbleConnection *, const GArray *contact_handles);
 
 G_END_DECLS
 
diff --git a/src/conn-presence.c b/src/conn-presence.c
index bc2b315..90e2786 100644
--- a/src/conn-presence.c
+++ b/src/conn-presence.c
@@ -139,7 +139,7 @@ construct_contact_statuses_cb (GObject *obj,
 
 
 /**
- * emit_presence_update:
+ * conn_presence_emit_presence_update:
  * @self: A #GabbleConnection
  * @contact_handles: A zero-terminated array of #TpHandle for
  *                    the contacts to emit presence for
@@ -147,9 +147,10 @@ construct_contact_statuses_cb (GObject *obj,
  * Emits the Telepathy PresenceUpdate signal with the current
  * stored presence information for the given contact.
  */
-static void
-emit_presence_update (GabbleConnection *self,
-                      const GArray *contact_handles)
+void
+conn_presence_emit_presence_update (
+    GabbleConnection *self,
+    const GArray *contact_handles)
 {
   GHashTable *contact_statuses;
 
@@ -162,7 +163,8 @@ emit_presence_update (GabbleConnection *self,
 
 /**
  * emit_one_presence_update:
  * Convenience function for calling emit_presence_update with one handle.
  */
 
 static void
@@ -172,7 +174,7 @@ emit_one_presence_update (GabbleConnection *self,
   GArray *handles = g_array_sized_new (FALSE, FALSE, sizeof (TpHandle), 1);
 
   g_array_insert_val (handles, 0, handle);
-  emit_presence_update (self, handles);
+  conn_presence_emit_presence_update (self, handles);
   g_array_free (handles, TRUE);
 }
 
@@ -275,7 +277,7 @@ connection_presences_updated_cb (
 {
   GabbleConnection *conn = GABBLE_CONNECTION (user_data);
 
-  emit_presence_update (conn, handles);
+  conn_presence_emit_presence_update (conn, handles);
 }
 
 
@@ -162,7 +163,8 @@ emit_presence_update (GabbleConnection *self,
 /**
  * emit_one_presence_update:
- * Convenience function for calling emit_presence_update with one handle.
+ * Convenience function for calling conn_presence_emit_presence_update with
+ * one handle.
  */
 
-- 
1.5.6.5




More information about the telepathy-commits mailing list